/*
 * Clock and power management (CPM) abstractions.
 *
 * Copyright (C) 2017, 2018, 2020 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <l4/sys/types.h>
#include <stdint.h>



#ifdef __cplusplus

/* A simple abstraction for accessing the CPM registers. */

class Cpm_chip
{
public:
  virtual uint32_t get_lcd_pixel_frequency() = 0;

  virtual void set_hdmi_frequency(uint32_t) { }

  virtual void start_hdmi() { }
  virtual void stop_hdmi() { }

  virtual void set_lcd_frequencies(uint32_t pclk, uint8_t ratio) = 0;

  virtual void start_lcd() = 0;
  virtual void stop_lcd() = 0;

  virtual void update_output_frequency() = 0;
};

#endif /* __cplusplus */
